@@ -2,7 +2,7 @@ package Plack::Middleware::Profiler::KYTProf;
 use strict;
 use warnings;
 use parent qw(Plack::Middleware);
-our $VERSION = '0.021';
+our $VERSION = '0.03';
 
 use Plack::Util::Accessor qw(
     namespace_regex
@@ -15,7 +15,7 @@ use Plack::Util::Accessor qw(
     mutes
     enable_profile_if
 );
-use Module::Load;
+use Module::Load qw(load);
 
 my %PROFILER_SETUPED;
 
@@ -47,7 +47,8 @@ sub start_profiling_if_needed {
 }
 
 sub _load_kytprof {
-    load 'Devel::KYTProf';
+    my $self = shift;
+    $self->_load_module('Devel::KYTProf');
 }
 
 sub _set_kytprof_options {
@@ -79,11 +80,18 @@ sub _load_profiles {
     $profiles
         ||= ['Plack::Middleware::Profiler::KYTProf::Profile::DefaultProfile'];
     foreach my $profile (@$profiles) {
-        load $profile;
+        $self->_load_module($profile);
+        die "profile class must implement load method"
+            unless $profile->can('load');
         $profile->load;
     }
 }
 
+sub _load_module {
+    my ( $self, $module ) = @_;
+    eval { load $module; 1; } or die "Can't load ${module}";
+}
+
 sub call {
     my ( $self, $env ) = @_;
     $self->start_profiling_if_needed($env);
